from functools import partial
from touchphat import *

_status = [False]*6
_names = ["BACK","A","B","C","D","ENTER"]

def _pressed(pad):
    global _status
    _status[pad] = True
    
def _released(pad):
    global _status
    _status[pad] = False
    
def touched(pad):
    """Returns True if the pad is touched
    Pad can be a number (0-5), a name ("BACK","A","B","C","D","ENTER"),
    or "ANY" (in which case it returns true if any pad is touched)"""
    if str(pad).upper()=="ANY":
        return any(_status)
    try:
        index = int(pad)
    except ValueError:
        try:
            index = _names.index(str(pad).upper())
        except ValueError:
            raise ValueError("{} is not the name of a pad".format(pad))
    return _status[index]
            
for i in range(6):
    on_touch(i+1, partial(_pressed, i))
    on_release(i+1, partial(_released, i))
        



import os
import smtplib
from email.mime.text import MIMEText
from email.mime.image import MIMEImage
from email.mime.multipart import MIMEMultipart
import ssl


def send(from_email, to_email, message, password, server="smtp.gmail.com", port=465):
	"""
	Send an email
	Use from_email and password to log in to server on specified port
	(defaults are set to gmail server)
	Then send an email to to_email with message
	First line of message must start with Subject:
	"""
	with smtplib.SMTP_SSL(server, port, context = ssl.create_default_context()) as connection:
		connection.login(from_email, password)
		connection.sendmail(from_email, to_email, message)

def sendImage(from_email, to_email, message, subject, password, attachment, server="smtp.gmail.com", port=465):
    """
    Send an image by email
	Use from_email and password to log in to server on specified port
	(defaults are set to gmail server)
	Then send an email to to_email with specified subject and message,
	including attachment (which is the filename of an image)
    """
	#setup the email
	msg = MIMEMultipart()
	msg['Subject'] = subject
	msg['From'] = from_email
	msg['To'] = to_email
	text = MIMEText(message)	
	msg.attach(text)
	
  #attach an image
	img_data = open(attachment, 'rb').read()
	image = MIMEImage(img_data, name=os.path.basename(attachment))
	msg.attach(image)		
	
	#send over ssl
	with smtplib.SMTP_SSL(server, port, context = ssl.create_default_context()) as connection:
		connection.login(from_email, password)
		connection.sendmail(from_email, to_email, msg.as_string())
